#!/bin/bash
#
# rc.firewall - Iptables firewall script for LAMP system.
#
# Copyright (C) 2003  Oskar Andreasson <bluefluxATkoffeinDOTnet>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program or from the site that you downloaded it
# from; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place, Suite 330, Boston, MA  02111-1307   USA
#
# $Id: rc.LAMP-firewall.sh,v 1.2 2003/05/16 14:23:09 blueflux Exp $
#

IPTABLES="/usr/sbin/iptables"

IP="192.168.0.2"
IFACE="eth0"

# Set defalt policies per chain.
$IPTABLES -P INPUT DROP
$IPTABLES -P OUTPUT DROP
$IPTABLES -P FORWARD DROP

# Improve disk IO on servers. kupdate will run every .6 seconds, dirty buffer flush every 3 secs.
echo 40 0 0 0 60 300 60 0 0 > /proc/sys/vm/bdflush

# Use SYN cookies. Controversial, and do break RFC's in a sense. Be cautious
echo 1 > /proc/sys/net/ipv4/tcp_syncookies

# Ignore broadcasted pings.
echo 1 > /proc/sys/net/ipv4/icmp_echo_ignore_broadcasts

# Increase TCP Receive memory buffer, to improve performance on high speed networks.
echo 8192 174760 349520 > /proc/sys/net/ipv4/tcp_rmem

# Increase TCP Send memory buffer, to improve performance on high speed networks.
echo 8192 32768 262144 > /proc/sys/net/ipv4/tcp_wmem

# Create out of the ordinary chains.

# Allowed chain.
$IPTABLES -N allowed
$IPTABLES -A allowed -p TCP --syn -j ACCEPT
$IPTABLES -A allowed -p TCP -m state --state ESTABLISHED,RELATED -j ACCEPT
$IPTABLES -A allowed -p TCP -j REJECT

# Ordinary chains. 

# INPUT chain

$IPTABLES -A INPUT -m state -i $IFACE --state ESTABLISHED,RELATED -j allowed
$IPTABLES -A INPUT -p tcp --destination $IP --dport 80 -j allowed
$IPTABLES -A INPUT -p tcp --destination $IP --dport 21 -j allowed
$IPTABLES -A INPUT -p tcp --destination $IP --dport 22 -j allowed
$IPTABLES -A INPUT -p tcp -i lo --dport 3306 -j allowed
$IPTABLES -A INPUT -p tcp -i lo --dport 25 -j allowed
$IPTABLES -A INPUT -p tcp -i lo --dport allowed

# OUTPUT chain

$IPTABLES -A OUTPUT -m state --state ESTABLISHED,RELATED -j ACCEPT
$IPTABLES -A OUTPUT -p tcp --dport 80 -j allowed
$IPTABLES -A OUTPUT -p tcp -o lo --dport 3306 -j allowed
$IPTABLES -A OUTPUT -p tcp -o lo --dport 25 -j allowed

# FORWARD chain is empty.

